<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Libs\Repositories\Contracts\LevelRepositoryInterface;
use Illuminate\Http\Request;

/**
 * Level controller
 */
class LevelController extends Controller
{
    /**
     * @var LevelRepositoryInterface
     */
    private  LevelRepositoryInterface $levelRepositoryInterface;

    /**
     * @param LevelRepositoryInterface $levelRepositoryInterface
     */
    public function __construct(LevelRepositoryInterface $levelRepositoryInterface)
    {
        $this->levelRepositoryInterface = $levelRepositoryInterface;
    }

    /**
     * get all levels
     * @return mixed
     */
    public function index(): mixed
    {
        return  $this->levelRepositoryInterface->getAllLevels();
    }

    /**
     * store level
     * @param Request $request
     * @return mixed
     */
    public function store(Request $request): mixed
    {
        return $this->levelRepositoryInterface->createLevel($request);
    }

    /**
     * show level
     * @param int $id
     * @return mixed
     */
    public function show(int $id): mixed
    {
        return $this->levelRepositoryInterface->getSingleLevel($id);
    }

    /**
     * update level
     * @param Request $request
     * @param int $id
     * @return mixed
     */
    public function update(Request $request, int $id): mixed
    {
        return $this->levelRepositoryInterface->updateLevel($request, $id);
    }

    /**
     * get all levels by category
     * @param $id
     * @return mixed
     */
    public function getAllLevelByCategoryMethod($id): mixed
    {
        return $this->levelRepositoryInterface->getAllLevelByCategory($id);
    }

    /**
     * delete level
     * @param int $id
     * @return mixed
     */
    public function destroy(int $id): mixed
    {
        return $this->levelRepositoryInterface->deleteLevel($id);
    }
}
