<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Libs\Services\PayStackService;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class PaystackController extends Controller
{
    /**
     * @var PayStackService
     */
    private PayStackService $payStackService;

    /**
     * @param PayStackService $payStackService
     */
    public function __construct(PayStackService $payStackService)
    {
        $this->payStackService = $payStackService;
    }

    /**
     * make payment using paystack
     * @param Request $request
     * @return JsonResponse
     */
    public function makePayment(Request $request): JsonResponse
    {
        $validator =  Validator::make($request->all(), [
            'student_id' => 'sometimes',
            'guardian_id' => 'sometimes',
            'plan_id' => 'required',
            'type' => 'required',
            'amount' => 'required',
            'description' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->errors()->first(),
                'success' => false
            ], 422);
        }else {
            return $this->payStackService->initializePaystackPaymentService($request);
        }
    }

    /**
     * verify  paystack payment
     * @param $reference
     * @return JsonResponse
     */
    public function verifyPayment($reference): JsonResponse
    {
        return $this->payStackService->verifyPaystackPaymentService($reference);
    }

}
