<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\ReviewResource;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Models\Review;
use Illuminate\Support\Facades\Validator;

/**
 * Review controller
 */
class ReviewController extends Controller
{
    /**
     * Handle the incoming request.
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function __invoke(Request $request): JsonResponse
    {
        $classes = (new \App\Models\Classes)->findOrFail($request->class_id);
        $validator =  Validator::make($request->all(),[
            'review_rating' => 'required|integer',
            'review_comment' => 'required',
            'class_id' => 'required|exists:classes,id'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            try {
                $review = Review::create([
                    'teacher_id' => $classes->teacher_id,
                    'review_rating' => $request->review_rating,
                    'review_comment' => $request->review_comment,
                    'class_id' => $request->class_id
                ]);
                return response()->json([
                    'message' => 'Review given successfully',
                    'data' => new ReviewResource($review),
                    'success' => true
                ]);
            } catch (\Exception $e) {
                return response()->json([
                    'message' => 'Sorry unable to give review',
                    'error' => $e->getMessage(),
                    'success' => false
                ], 400);
            }
        }
    }
}
