<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Libs\Repositories\Contracts\StudentRepositoryInterface;
use Illuminate\Http\Request;

/**
 * Student controller
 */
class StudentController extends Controller
{

    /**
     * @var StudentRepositoryInterface
     */
    private StudentRepositoryInterface $studentRepositoryInterface;

    /**
     * @param StudentRepositoryInterface $studentRepositoryInterface
     */
    public function __construct(StudentRepositoryInterface $studentRepositoryInterface)
    {
        $this->studentRepositoryInterface = $studentRepositoryInterface;
    }

    /**
     * get all index
     * @return mixed
     */
    public function index(): mixed
    {
        return $this->studentRepositoryInterface->getAllStudents();
    }

    /**
     * create student
     * @param Request $request
     * @return mixed
     */
    public function store(Request $request): mixed
    {
        return $this->studentRepositoryInterface->createStudentAccount($request);
    }

    /**
     * show all students
     * @param $id
     * @return mixed
     */
    public function show($id): mixed
    {
        return $this->studentRepositoryInterface->getSingleStudent($id);
    }

    /**
     * update student details
     * @param Request $request
     * @param $id
     * @return mixed
     */
    public function update(Request $request, $id): mixed
    {
        return $this->studentRepositoryInterface->updateStudentAccount($request, $id);
    }

    /**
     * delete students
     * @param $id
     * @return mixed
     */
    public function destroy($id): mixed
    {
        return $this->studentRepositoryInterface->deleteStudent($id);
    }
}
