<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Libs\Repositories\Contracts\SubjectRepositoryInterface;
use Illuminate\Http\Request;

/**
 * Subject controller
 */
class SubjectController extends Controller
{
    /**
     * @var SubjectRepositoryInterface
     */
    private  SubjectRepositoryInterface $subjectRepositoryInterface;

    /**
     * @param SubjectRepositoryInterface $subjectRepositoryInterface
     */
    public function __construct(SubjectRepositoryInterface $subjectRepositoryInterface)
    {
        $this->subjectRepositoryInterface = $subjectRepositoryInterface;
    }

    /**
     * get all subject
     * @return mixed
     */
    public function index(): mixed
    {
        return  $this->subjectRepositoryInterface->getAllSubjects();
    }

    /**
     * store subject
     * @param Request $request
     * @return mixed
     */
    public function store(Request $request): mixed
    {
        return $this->subjectRepositoryInterface->createSubject($request);
    }

    /**
     * show subject
     * @param int $id
     * @return mixed
     */
    public function show(int $id): mixed
    {
        return  $this->subjectRepositoryInterface->getSingleSubject($id);
    }

    /**
     * get all subject by category
     * @param $id
     * @return mixed
     */
    public function getAllSubjectByCategoryMethod($id): mixed
    {
        return $this->subjectRepositoryInterface->getAllSubjectByCategory($id);
    }

    /**
     * update subject
     * @param Request $request
     * @param int $id
     * @return mixed
     */
    public function update(Request $request, int $id): mixed
    {
        return $this->subjectRepositoryInterface->updateSubject($request, $id);
    }

    /**
     * delete subject
     * @param int $id
     * @return mixed
     */
    public function destroy(int $id): mixed
    {
        return $this->subjectRepositoryInterface->deleteSubject($id);
    }

}
