<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Libs\Repositories\Contracts\TeacherRepositoryInterface;

/**
 * Teachers controller
 */
class TeacherController extends Controller
{
    /**
     * @var TeacherRepositoryInterface
     */
    private TeacherRepositoryInterface $teacherRepositoryInterface;

    /**
     * @param TeacherRepositoryInterface $teacherRepositoryInterface
     */
    public function __construct(TeacherRepositoryInterface $teacherRepositoryInterface)
    {
        $this->teacherRepositoryInterface = $teacherRepositoryInterface;
    }

    /**
     * add subject for teacher
     * @param Request $request
     * @return mixed
     */
    public function addSubjectMethod(Request $request): mixed
    {
        return $this->teacherRepositoryInterface->addSubjects($request);
    }

    /**
     * update teachers educational qualification
     * @param Request $request
     * @return mixed
     */
    public function updateTeachersEducationalQualificationMethod(Request $request): mixed
    {
        return $this->teacherRepositoryInterface->updateEducationalQualification($request);
    }

    /**
     * approve teachers account method
     * @param $slug
     * @return mixed
     */
    public function approveTeachersAccountMethod($slug): mixed
    {
        return $this->teacherRepositoryInterface->approveTeachersAccount($slug);
    }

    /**
     * get teachers by subject
     * @param Request $request
     * @return mixed
     */
    public function getTeachersBySubjectMethod(Request $request): mixed
    {
        return $this->teacherRepositoryInterface->getTeachersBySubject($request);
    }

    /**
     * get single teacher
     * @param $id
     * @return mixed
     */
    public function getSingleTeachersMethod($id): mixed
    {
        return $this->teacherRepositoryInterface->getSingleTeachers($id);
    }

    /**
     * get all teachers
     * @return mixed
     */
    public function getAllTeachersMethod(): mixed
    {
        return $this->teacherRepositoryInterface->getAllTeachers();
    }

}
