<?php

namespace App\Http\Resources;

use App\Libs\Helpers\SystemHelper;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @property mixed $id
 * @property mixed $phone_number
 * @property mixed $updated_at
 * @property mixed $created_at
 * @property mixed $deleted_at
 * @property mixed $first_name
 * @property mixed $last_name
 * @property mixed $subjects
 * @property mixed $school_attend
 * @property mixed $degree_attained
 * @property mixed $certificate_url
 * @property mixed $is_approved
 * @property mixed $category
 * @property mixed $slug
 * @property mixed $address
 * @property mixed $bio
 * @property mixed $classes
 * @property mixed $courseWorks
 */
class TeacherResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $helper = new SystemHelper();
        return [
            'id' => $this->id,
            'firstname' => $helper->cleanStringHelper($this->first_name),
            'lastname' => $helper->cleanStringHelper($this->last_name),
            'phone_number' => $helper->cleanStringHelper($this->phone_number),
            'address' => $helper->cleanStringHelper($this->address),
            'school_attend'  => $helper->cleanStringHelper($this->school_attend),
            'degree_attained'  => $helper->cleanStringHelper($this->degree_attained),
            'certificate_url'  => $helper->cleanStringHelper($this->certificate_url),
            'bio' => $helper->cleanStringHelper($this->bio),
            'is_approved' => $this->is_approved === 0 ? 'false' : 'true',
            'slug' => $helper->cleanStringHelper($this->slug),
            'review_rating' => $helper->reviewAnalytics($this),
            'relationships' => [
                'course_works' => $this->courseWorks,
                'category' => new CategoryResource($this->category),
                'classes' => ClassesResource::collection($this->classes)
            ],
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
            'deleted_at' => $this->deleted_at
        ];
    }
}
