<?php

namespace App\Libs\Actions;

use App\Http\Resources\AdminResource;
use App\Libs\Enums\RolesEnum;
use App\Models\User;
use App\Http\Resources\UserResource;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\DB;
use App\Models\Admin;

/**
 * Admin Action
 */
class AdminAction
{
    /**
     * @var User
     */
    private User $model;
    private  Admin $admin_model;

    /**
     * @param User $model
     * @param Admin $admin_model
     */
    public function __construct(User $model, Admin $admin_model)
    {
        $this->model = $model;
        $this->admin_model = $admin_model;
    }

    /**
     * create admin account
     * @param $request
     * @return JsonResponse
     */
    public function createAdminAccountAction($request): JsonResponse
    {
        DB::beginTransaction();
        try {
            $admin = $this->model->create([
                'email' => $request->email,
                'password' => bcrypt('Password@1'),
                'role' => RolesEnum::ADMIN
            ]);
            $admin->admin()->create([
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'phone_number' => $request->phone_number,
                'address' => $request->address
            ]);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'message' => 'Sorry unable to create admin account',
                'error' => $e->getMessage(),
                'success' => false
            ], 400);
        }
        DB::commit();
        return response()->json([
            'message' => 'Account created successfully',
            'data' => new UserResource($this->model->find($admin->id)),
            'success' => true
        ], 201);
    }

    /**
     * get all admin accounts
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllAdminAccountAction(): JsonResponse|AnonymousResourceCollection
    {
        $admins = $this->admin_model->with(['user'])->latest()->paginate(10);
        if (count($admins) < 1) {
            return response()->json([
                'message' => 'Sorry no admin head teacher found',
                'success' => false
            ], 404);
        }else {
            return AdminResource::collection($admins)->additional([
                'message' => "All admin head teachers",
                'success' => true
            ], 200);
        }
    }

    /**
     * get single admin
     * @param $id
     * @return AdminResource
     */
    public function getSingleAdminAccountAction($id): AdminResource
    {
        $admin = $this->admin_model->findOrFail($id);
        return (new  AdminResource($admin))->additional( [
            'message' => "Admin details",
            'success' => true
        ], 200);
    }

    /**
     * delete admin
     * @param $id
     * @return JsonResponse
     */
    public function deleteAdminAccountAction($id): JsonResponse
    {
        $admin =  $this->admin_model->findOrFail($id);
        try {
            $admin->delete();
            $admin->user->delete();
            return response()->json([
                'message' => 'Admin head teacher deleted successfully',
                'data' => new AdminResource($admin),
                'success' => true
            ], 200);
        }catch (\Exception $e) {
            return response()->json([
                'message' => 'Sorry unable to delete admin head teacher',
                'error' => $e->getMessage(),
                'success' => false
            ], 400);
        }
    }

}
