<?php

namespace App\Libs\Actions;

use App\Libs\Traits\AuthUserTrait;
use App\Models\Classes;
use App\Http\Resources\ClassesResource;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;

/**
 *
 */
class ClassesAction
{
    use AuthUserTrait;

    /**
     * @var Classes
     */
    private Classes $model;

    /**
     * @param Classes $model
     */
    public function __construct(Classes $model)
    {
        $this->model = $model;
    }

    /**
     * get all classes
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllClassesAction(): JsonResponse|AnonymousResourceCollection
    {
        $classes = $this->getAuthUser()->superadmin ? $this->model->latest()->paginate(20) :
            $this->model->where('teacher_id', '=', $this->getAuthUser()->teacher->id)->latest()->paginate(20);
        if (count($classes) < 1) {
            return response()->json([
                'message' => 'Sorry no class found',
                'success' => false
            ], 404);
        } else {
            return ClassesResource::collection($classes)->additional([
                'message' => "All classes",
                'success' => true
            ], 200);
        }
    }

    /**
     * get single class
     * @param $id
     * @return ClassesResource
     */
    public function getSingleClassAction($id): ClassesResource
    {
        $class = $this->model->findOrFail($id);
        return (new ClassesResource($class))->additional( [
            'message' => "Class details",
            'success' => true
        ], 200);
    }

}
