<?php

namespace App\Libs\Actions;

use App\Libs\Traits\AuthUserTrait;
use App\Models\CourseWork;
use App\Http\Resources\CourseWorkResource;
use App\Libs\Helpers\FileProcessing;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;

/**
 * course work action
 */
class CourseWorkAction
{
    use AuthUserTrait;

    /**
     * @var CourseWork
     */
    private CourseWork $model;
    /**
     * @var FileProcessing
     */
    private FileProcessing $fileProcessingHelper;

    /**
     * @param CourseWork $model
     * @param FileProcessing $fileProcessingHelper
     */
    public function __construct(CourseWork $model, FileProcessing $fileProcessingHelper)
    {
        $this->model = $model;
        $this->fileProcessingHelper = $fileProcessingHelper;
    }

    /**
     * add course work
     * @param $request
     * @return JsonResponse
     */
    public function addCourseWorkAction($request): JsonResponse
    {
        try {
            $course_work = $this->model->create([
                'subject_id' => $request->subject_id,
                'teacher_id' => $this->getAuthUser()->teacher->id,
                'pdf_link' => $this->fileProcessingHelper->pushImageFile($request, 'pdf_link')
            ]);
            return response()->json([
                'message' => 'Course work created successfully',
                'data' => new CourseWorkResource($course_work),
                'success' => true
            ], 201);
        }catch (\Exception $e) {
            return response()->json([
                'message' => 'Sorry unable to  create course work',
                'error' => $e->getMessage(),
                'success' => false
            ], 400);
        }
    }

    /**
     * get all course works
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllMyCourseWorkAction(): JsonResponse|AnonymousResourceCollection
    {
        $course_works = $this->getAuthUser()->superadmin ? $this->model->latest()->paginate(20) :
            $this->model->where('teacher_id', '=', $this->getAuthUser()->teacher->id)->latest()->paginate(20);
        if (count($course_works) < 1) {
            return response()->json([
                'message' => 'Sorry no course work found',
                'success' => false
            ], 404);
        }else {
            return CourseWorkResource::collection($course_works)->additional([
                'message' => "All course work",
                'success' => true
            ], 200);
        }
    }

    /**
     * get single course work
     *
     * @param $id
     * @return CourseWorkResource
     */
    public function getSingleCourseWorkAction($id): CourseWorkResource
    {
        $course_work = $this->model->findOrFail($id);
        return (new CourseWorkResource($course_work))->additional( [
            'message' => "Course work details",
            'success' => true
        ], 200);
    }



}
