<?php

namespace App\Libs\Repositories;

use App\Http\Resources\AdminResource;
use App\Libs\Actions\AdminAction;
use App\Libs\Repositories\Contracts\AdminRepositoryInterface;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * AdminRepository
 */
class AdminRepository implements AdminRepositoryInterface
{
    /**
     * @var AdminAction
     */
    private AdminAction $action;

    /**
     * @param AdminAction $action
     */
    public function __construct(AdminAction $action)
    {
        $this->action = $action;
    }

    /**
     * create admin account
     * @param $request
     * @return JsonResponse
     */
    public function createAdminAccount($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:users,email',
            'phone_number' => 'required',
            'address' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return $this->action->createAdminAccountAction($request);
        }
    }

    /**
     * get all admin
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllAdminAccount(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllAdminAccountAction();
    }

    /**
     * get single admin
     * @param $id
     * @return AdminResource
     */
    public function getSingleAdminAccount($id):AdminResource
    {
        return $this->action->getSingleAdminAccountAction($id);
    }

    /**
     * delete admin
     * @param $id
     * @return JsonResponse
     */
    public function deleteAdminAccount($id): JsonResponse
    {
        return $this->action->deleteAdminAccountAction($id);
    }
}
