<?php

namespace App\Libs\Repositories;

use App\Http\Resources\CourseWorkResource;
use App\Libs\Actions\CourseWorkAction;
use App\Libs\Repositories\Contracts\CourseWorkRepositoryInterface;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * CourseWorkRepository
 */
class CourseWorkRepository implements CourseWorkRepositoryInterface
{
    /**
     * @var CourseWorkAction
     */
    private CourseWorkAction $action;

    /**
     * @param CourseWorkAction $action
     */
    public function __construct(CourseWorkAction $action)
    {
        $this->action = $action;
    }

    /**
     * add course work
     * @param $request
     * @return JsonResponse
     */
    public function addCourseWork($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'subject_id'  => 'required',
            'pdf_link' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->addCourseWorkAction($request);
        }
    }

    /**
     * get all course work
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllMyCourseWork(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllMyCourseWorkAction();
    }

    /**
     * get single course work
     * @param $id
     * @return CourseWorkResource
     */
    public function getSingleCourseWork($id): CourseWorkResource
    {
        return $this->action->getSingleCourseWorkAction($id);
    }

}
