<?php

namespace App\Libs\Repositories;

use App\Http\Resources\LevelResource;
use App\Libs\Actions\LevelAction;
use App\Libs\Repositories\Contracts\LevelRepositoryInterface;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * Level repository
 */
class LevelRepository implements  LevelRepositoryInterface
{
    /**
     * @var LevelAction
     */
    private LevelAction $action;

    /**
     * @param LevelAction $action
     */
    public function __construct(LevelAction $action)
    {
        $this->action = $action;
    }

    /**
     * create level
     * @param $request
     * @return JsonResponse
     */
    public function createLevel($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'category_id' => 'required',
            'name' => 'required',
            'description' => 'required',
        ],[
            'category_id.exists' => 'Please choose a category',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->createLevelAction($request);
        }
    }

    /**
     * get single level
     * @param $id
     * @return LevelResource
     */
    public function getSingleLevel($id): LevelResource
    {
        return $this->action->getSingleLevelAction($id);
    }

    /**
     * get all levels by category
     * @param $id
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllLevelByCategory($id): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllLevelByCategoryAction($id);
    }

    /**
     * get all levels
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllLevels(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllLevelAction();
    }

    /**
     * update level
     * @param $request
     * @param $id
     * @return JsonResponse
     */
    public function updateLevel($request, $id): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'name' => 'sometimes',
            'description' => 'sometimes',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->updateLevelAction($request, $id);
        }
    }

    /**
     * delete level
     * @param $id
     * @return JsonResponse
     */
    public function deleteLevel($id): JsonResponse
    {
        return $this->action->deleteLevelAction($id);
    }
}
