<?php

namespace App\Libs\Repositories;

use App\Http\Resources\StudentResource;
use App\Libs\Repositories\Contracts\StudentRepositoryInterface;
use App\Libs\Actions\StudentAction;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * Student repostory
 */
class StudentRepository implements StudentRepositoryInterface
{
    /**
     * @var StudentAction
     */
    private StudentAction $action;

    /**
     * @param StudentAction $action
     */
    public function __construct(StudentAction $action)
    {
        $this->action = $action;
    }

    /**
     * create student
     * @param $request
     * @return JsonResponse
     */
    public function createStudentAccount($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'age' => 'required',
            'level_id' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return $this->action->createStudentAccountAction($request);
        }
    }

    /**
     * get all student
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllStudents(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllStudentsAction();
    }

    /**
     * get single student
     * @param $id
     * @return StudentResource
     */
    public function getSingleStudent($id): StudentResource
    {
        return $this->action->getSingleStudentAction($id);
    }

    /**
     * update student
     * @param $request
     * @param $id
     * @return JsonResponse
     */
    public function updateStudentAccount($request, $id): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'name' => 'sometimes',
            'age' => 'sometimes',
            'level_id' => 'sometimes'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->updateStudentAccountAction($request, $id);
        }
    }

    /**
     * delete student
     * @param $id
     * @return JsonResponse
     */
    public function deleteStudent($id): JsonResponse
    {
        return $this->action->deleteStudentAction($id);
    }

}
