<?php

namespace App\Libs\Repositories;

use App\Http\Resources\SubjectResource;
use App\Libs\Actions\SubjectAction;
use App\Libs\Repositories\Contracts\SubjectRepositoryInterface;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * Subject Repository
 */
class SubjectRepository implements  SubjectRepositoryInterface
{
    /**
     * @var SubjectAction
     */
    private SubjectAction $action;

    /**
     * @param SubjectAction $action
     */
    public function __construct(SubjectAction $action)
    {
        $this->action = $action;
    }

    /**
     * create subject method
     * @param $request
     * @return JsonResponse
     */
    public function createSubject($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'category_id' => 'required',
            'name' => 'required',
            'description' => 'required',
        ],[
            'category_id.exists' => 'Please choose a category',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->createSubjectAction($request);
        }
    }

    /**
     * get all subjects by category
     * @param $id
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllSubjectByCategory($id): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllSubjectByCategoryAction($id);
    }

    /**
     * get single method
     * @param $id
     * @return SubjectResource
     */
    public function getSingleSubject($id): SubjectResource
    {
        return $this->action->getSingleSubjectAction($id);
    }

    /**
     * get all subject
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllSubjects(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllSubjectAction();
    }

    /**
     * update subject method
     * @param $request
     * @param $id
     * @return JsonResponse
     */
    public function updateSubject($request, $id): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'name' => 'sometimes',
            'description' => 'sometimes',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->updateSubjectAction($request, $id);
        }
    }

    /**
     * delete subject
     * @param $id
     * @return JsonResponse
     */
    public function deleteSubject($id): JsonResponse
    {
        return $this->action->deleteSubjectAction($id);
    }

}
