<?php

namespace App\Libs\Repositories;

use App\Http\Resources\ClassesResource;
use App\Libs\Repositories\Contracts\TeacherRequestRepositoryInterface;
use App\Libs\Actions\TeacherRequestAction;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Support\Facades\Validator;

/**
 * Teacher request repository
 */
class TeacherRequestRepository implements TeacherRequestRepositoryInterface
{
    /**
     * @var TeacherRequestAction
     */
    private TeacherRequestAction $action;

    /**
     * @param TeacherRequestAction $action
     */
    public function __construct(TeacherRequestAction $action)
    {
        $this->action = $action;
    }

    /**
     * engage teacher
     * @param $request
     * @return JsonResponse
     */
    public function engageTeacher($request): JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'teacher_id' => 'required|exists:teachers,id',
            'student_id' => 'required|exists:students,id',
            'subject_id' => 'required|exists:subjects,id'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->engageTeacherByStudentAction($request);
        }
    }

    /**
     * approve teachers engagement
     * @param $request
     * @return JsonResponse|null
     */
    public function approveTeacherEngagement($request): ?JsonResponse
    {
        $validator = Validator::make($request->all(), [
            'engagement_id' => 'required',
            'class_id' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()->first(),
                'success' => false
            ], 422);
        }else {
            return  $this->action->approveEngagementRequestAction($request);
        }
    }

    /**
     * get all meeting links
     * @param $id
     * @return ClassesResource|JsonResponse
     */
    public function getMeetingLink($id): JsonResponse|ClassesResource
    {
        return $this->action->getMeetingLinkAction($id);
    }

    /**
     * get all engagements
     * @return JsonResponse|AnonymousResourceCollection
     */
    public function getAllEngagement(): JsonResponse|AnonymousResourceCollection
    {
        return $this->action->getAllEngagementAction();
    }

}
