<?php

namespace App\Libs\Services;

use App\Models\Classes;
use Carbon\Carbon;
use MacsiDigital\Zoom\Facades\Zoom;

/**
 * Zoom service
 */
class ZoomService
{
    /**
     * create Zoom meeting
     * @return void
     */
    public function createMeeting(): void
    {
        $user = Zoom::user()->find(config('zoom.client_id'));
        $classes = Classes::where('day', '=', Carbon::now()->englishDayOfWeek)->get();
        foreach ($classes as $class) {
            $meeting = $user->meetings()->create([
                'topic' => $class->subject->name,
                'type' => '2',
                'timezone' => 'West Central Africa',
                'duration' => 60,
                'start_time' =>  $class->time.''.$class->variation,
            ]);
            $meeting->settings()->make([
                'host_video' => true,
                'participant_video' => true,
                'join_before_host' => true,
                'approval_type' => 1,
                'registration_type' => 2,
                'enforce_login' => false,
                'waiting_room' => false,
                'auto_recording' => 'cloud',
            ]);
            Classes::where('id', '=', $class->id)->update([
                'meeting_type' => 'zoom',
                'meeting_details' => json_encode(array('url' => $meeting->join_url, 'meeting_id' => $meeting->id, 'time_zone' => $meeting->timezone, 'start_time' => $meeting->start_time ), JSON_FORCE_OBJECT)
            ]);
        }
    }

    /**
     * get all zoom meeting
     * @return mixed
     */
    public function allMyMeetings(): mixed
    {
        return Zoom::user()->find(config('zoom.client_id'))->meetings()->where('type', 'scheduled')->get();
    }

    /**
     * get meeting recording
     * @param $id
     * @return mixed
     */
    public function meetingRecording($id): mixed
    {
        return Zoom::meeting()->find($id)->recordings;
    }

}
