<?php

namespace App\Models;

use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * @method create(array $array)
 * @method inRandomOrder()
 * @method static whereMonth(string $string, string $string1, int $month)
 * @method static whereYear(string $string, string $string1, int $year)
 * @method static where(string $string, string $string1, bool $true)
 */
class Guardian extends Model
{
    use HasFactory, SoftDeletes, Sluggable;

    protected  $fillable = [
        'user_id', 'first_name', 'last_name', 'phone_number', 'address', 'from_date', 'to_date', 'is_subscribed', 'plan_id'
    ];

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function plan(): BelongsTo
    {
        return $this->belongsTo(Plan::class, 'plan_id');
    }

    public function transactions(): HasMany
    {
        return $this->hasMany(Transaction::class);
    }

    public function students()
    {
        return $this->hasMany(Student::class);
    }

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'first_name'
            ]
        ];
    }


}
