<?php

namespace App\Models;

use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasManyThrough;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * @method create(array $array)
 * @method latest()
 * @method findOrFail($id)
 * @method where(string $string, string $string1, $id)
 */
class Student extends Model
{
    use HasFactory, SoftDeletes, Sluggable;

    protected  $fillable = [
        'guardian_id', 'name', 'age',  'level_id'
    ];

    public function guardian(): BelongsTo
    {
        return $this->belongsTo(Guardian::class, 'guardian_id');
    }

    public function teachersEngagements(): HasMany
    {
        return $this->hasMany(TeacherRequest::class);
    }

    public function myClasses(): HasManyThrough
    {
        return $this->hasManyThrough(
            Classes::class,
            TeacherRequest::class,
            'student_id', // Foreign key on the environments table...
            'subject_id', // Foreign key on the deployments table...
            'id', // Local key on the projects table...
            'student_id' // Local key on the environments table...
        );
    }

    public function level(): BelongsTo
    {
        return $this->belongsTo(Level::class, 'level_id');
    }

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'name'
            ]
        ];
    }

}
