<?php

namespace App\Models;

use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * @method create(array $array)
 * @method where(string $string, string $string1, $id)
 * @method whereJsonContains(string $string, $name)
 * @method whereHas(string $string, \Closure $param)
 * @method latest()
 * @method findOrFail($id)
 */
class Teacher extends Model
{
    use HasFactory, SoftDeletes, Sluggable;

    protected  $fillable = [
        'user_id', 'first_name', 'category_id', 'bio', 'is_approved', 'last_name', 'school_attend', 'degree_attained', 'certificate_url', 'phone_number', 'address', 'slug'
    ];

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function category() : BelongsTo
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function subjects(): HasMany
    {
        return $this->hasMany(TeacherSubject::class);
    }

    public function courseWorks(): HasMany
    {
        return $this->hasMany(CourseWork::class);
    }

    public function classes(): HasMany
    {
        return $this->hasMany(Classes::class);
    }

    public function reviews(): HasMany
    {
        return $this->hasMany(Review::class);
    }

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'first_name'
            ]
        ];
    }

}
