<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Relations\HasOne;
use Laravel\Sanctum\HasApiTokens;
use App\Libs\Traits\UsesUuidTrait;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

/**
 * @method where(string $string, string $string1, $email)
 * @method find($id)
 * @method create(array $array)
 * @method latest()
 * @method findOrFail($id)
 */
class User extends Authenticatable implements MustVerifyEmail
{
    use HasApiTokens, HasFactory, Notifiable, UsesUuidTrait, SoftDeletes;

    protected $fillable = [
        'email','password', 'role', 'is_active', 'email_verified_at'
    ];

    protected $hidden = [
        'password',
        'remember_token',
    ];

    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function teacher(): HasOne
    {
        return $this->hasOne(Teacher::class);
    }

   public function guardian(): HasOne
   {
        return $this->hasOne(Guardian::class);
   }

   public function admin(): HasOne
   {
        return $this->hasOne(Admin::class);
   }

    public function superadmin(): HasOne
    {
        return $this->hasOne(SuperAdmin::class);
    }


    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }

}
