<?php

use App\Http\Controllers\Api\AdminController;
use App\Http\Controllers\Api\AuthController;
use App\Http\Controllers\Api\CategoryController;
use App\Http\Controllers\Api\ClassesController;
use App\Http\Controllers\Api\CourseWorkController;
use App\Http\Controllers\Api\EmailVerificationController;
use App\Http\Controllers\Api\ForgotPasswordController;
use App\Http\Controllers\Api\LevelController;
use App\Http\Controllers\Api\PaystackController;
use App\Http\Controllers\Api\PlanController;
use App\Http\Controllers\Api\ReviewController;
use App\Http\Controllers\Api\StudentController;
use App\Http\Controllers\Api\SubjectController;
use App\Http\Controllers\Api\TeacherController;
use App\Http\Controllers\Api\TeacherRequestController;
use App\Http\Controllers\Api\UserController;
use Carbon\Carbon;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::group(['middleware' => 'api', 'prefix' => 'v1'], function ($router) {

    Route::get('/carbon', function () {
        $dt = Carbon::now();
        return $dt->englishDayOfWeek;
    });
    Route::controller(EmailVerificationController::class)->group(function () {
        Route::post('verify-account',  'verify');
    });

    Route::controller(ForgotPasswordController::class)->group(function () {
        Route::post('password-email',  'send');
        Route::post('password-reset',  'reset');
    });

    Route::group(['middleware' => ['auth:sanctum']], function () { //only authenticated users have access to this routes

        Route::post('reviews', ReviewController::class); // review

        Route::controller(AuthController::class)->group(function () { // Logout and view user profile
            Route::post('logout',  'logout');
            Route::get('user-profile', 'userProfile');
            Route::post('login','login')->withoutMiddleware(['auth:sanctum']);
        });

        Route::controller(ClassesController::class)->group(function () { // Classes controller
            Route::get('classes',  'index');
            Route::get('classes/{id}', 'show');
        });

        Route::controller(PaystackController::class)->group(function () { // payment routes
            Route::post('make-payment',  'makePayment');
            Route::get('verify-payment/{reference}', 'verifyPayment');
        });

        Route::controller(UserController::class)->group(function () { //users controllers
            Route::patch('change-password',  'changeAccountPassword');
            Route::patch('update-profile',  'updateUserProfile');
            Route::post('create-account',  'store')->withoutMiddleware(['auth:sanctum']);
            Route::post('change-account-status',  'activateOrDeactivateMethod')->withoutMiddleware(['auth:sanctum', 'is.superadmin']);
            Route::post('resend-verification-otp',  'resendOtpCode')->withoutMiddleware(['auth:sanctum']);
        });

        Route::controller(TeacherRequestController::class)->group(function () { // teacher request controllers
            Route::post('engage-teacher',  'engageTeacherMethod');
            Route::get('get-all-engagements',  'getAllEngagementMethod');
            Route::get('get-meeting-link/{id}',  'getMeetingLinkMethod');
            Route::post('approve-teachers-engagement',  'approveEngagementMethod');
        });

        Route::controller(TeacherController::class)->group(function () { //add subject controllers
            Route::patch('add-subjects',  'addSubjectMethod');
            Route::post('add-qualifications',  'updateTeachersEducationalQualificationMethod');
            Route::put('approve-teachers-account/{slug}',  'approveTeachersAccountMethod')->middleware(['is.admin']);
            Route::post('get-teachers',  'getTeachersBySubjectMethod')->withoutMiddleware(['auth:sanctum']);
            Route::get('teachers',  'getAllTeachersMethod')->withoutMiddleware(['auth:sanctum']);
            Route::get('teachers/{id}',  'getSingleTeachersMethod')->withoutMiddleware(['auth:sanctum']);
        });

        Route::controller(StudentController::class)->group(function () { // students routes
            Route::post('students',  'store');
            Route::get('students',  'index');
            Route::get('students/{id}',  'show');
            Route::patch('students/{id}',  'update');
            Route::delete('students/{id}',  'destroy');
        });

        Route::controller(CourseWorkController::class)->group(function () { // course work routes
            Route::post('course-works',  'addCourseWorkMethod');
            Route::get('course-works',  'getAllMyCourseWork');
            Route::get('course-works/{id}',  'getSingleCourseWork');
        });

        Route::group(['middleware' => ['is.superadmin']], function () { //only superadmin authenticated routes
            Route::controller(CategoryController::class)->group(function () { // categories routes
                Route::post('categories',  'store');
                Route::get('categories',  'index')->withoutMiddleware(['is.admin', 'is.superadmin', 'auth:sanctum']);
                Route::get('categories/{id}',  'show');
                Route::patch('categories/{id}',  'update');
                Route::delete('categories/{id}',  'destroy');
            });

            Route::controller(SubjectController::class)->group(function () { // subject routes
                Route::post('subjects',  'store');
                Route::get('subjects',  'index')->withoutMiddleware(['is.admin', 'is.superadmin', 'auth:sanctum']);
                Route::get('subjects/{id}',  'show');
                Route::get('subjects-by-category/{id}',  'getAllSubjectByCategoryMethod')->withoutMiddleware(['is.admin', 'is.superadmin', 'auth:sanctum']);
                Route::patch('subjects/{id}',  'update');
                Route::delete('subjects/{id}',  'destroy');
            });

            Route::controller(LevelController::class)->group(function () { // levels routes
                Route::post('levels',  'store');
                Route::get('levels',  'index')->withoutMiddleware(['is.admin', 'is.superadmin', 'auth:sanctum']);
                Route::get('levels/{id}',  'show');
                Route::get('levels-by-category/{id}',  'getAllLevelByCategoryMethod')->withoutMiddleware(['is.admin', 'is.superadmin', 'auth:sanctum']);
                Route::patch('levels/{id}',  'update');
                Route::delete('levels/{id}',  'destroy');
            });

            Route::controller(PlanController::class)->group(function () { // plans routes
                Route::post('plans',  'store');
                Route::get('plans',  'index')->withoutMiddleware(['is.superadmin']);
                Route::get('plans/{id}',  'show')->withoutMiddleware(['is.superadmin']);
                Route::patch('plans/{id}',  'update');
                Route::delete('plans/{id}',  'destroy');
            });

            Route::controller(AdminController::class)->group(function () { // admin routes
                Route::post('admins',  'store');
                Route::get('admins',  'index');
                Route::get('admins/{id}',  'show');
                Route::delete('admins/{id}',  'destroy');
            });

        });

    });

});
