<?php

namespace Tests\Feature;

use App\Http\Controllers\Api\UserController;
use App\Libs\Actions\UserAction;
use App\Libs\Repositories\UserRepository;
use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;

class UserControllerTest extends TestCase
{
    use RefreshDatabase;

    public function test_user_registration_successful(): void
    {
        $response = $this->post('/api/v1/create-account', [
            "first_name" => "Orutu",
            "last_name" => "Akposieyefa",
            "email" => "orutu10@gmail.com",
            "password" => "Password@1",
            "password_confirmation" => "Password@1",
            "user_type" => "student",
            "phone_number" => "08100888865",
        ]);
        $response->assertStatus(201);
    }

    public function test_registration_validation_failed(): void
    {
        $response = $this->post('/api/v1/create-account', [
            "first_name" => "",
            "last_name" => "Akposieyefa",
            "email" => "orutu10@gmail.com",
            "password" => "Password@1",
            "password_confirmation" => "Password@1",
            "user_type" => "student",
            "phone_number" => "08100888865",
        ]);
        $response->assertStatus(422);
    }

    public function test_user_change_password_is_successful()
    {

        $user = User::factory()->create();
        Sanctum::actingAs($user);

        $response = $this->patchJson('api/v1/change-password', [
            'old_password' => 'password',
            'password' => 'TechsharkOrutu@1',
            'password_confirmation' => 'TechsharkOrutu@1'
        ]);
       $response->assertStatus(200);
    }

    public function test_change_password_fail() {
        $user = User::factory()->create();
        Sanctum::actingAs($user);

        $response = $this->patchJson('api/v1/change-password', [
            'old_password' => 'passwordAs',
            'password' => 'TechsharkOrutu@1',
            'password_confirmation' => 'TechsharkOrutu@1'
        ]);
        $response->assertStatus( 402);
    }

    public function test_if_class_has_attribute()
    {
        $this->assertClassHasAttribute('userRepositoryInterface', UserController::class);
        $this->assertClassHasAttribute('action', UserRepository::class);
        $this->assertClassHasAttribute('model', UserAction::class);
        $this->assertClassHasAttribute('system_helper', UserAction::class);
    }

}
